==> mcu_plus_sdk_am263x_08_06_00_34_docs_only.tar.xz: mcu_plus_sdk_am263x_08_06_00_34_docs_only/docs/api_guide_am263x/group__BOARD__FLASH__MODULE.js <==
var group__BOARD__FLASH__MODULE =
[
    [ "Flash_DevConfig", "structFlash__DevConfig.html", [
      [ "cmdExtType", "structFlash__DevConfig.html#af9aaea904629353d937dc22dc5837b94", null ],
      [ "byteOrder", "structFlash__DevConfig.html#a03033dffd93a0ad57463b274b0a83ff2", null ],
      [ "enable4BAddr", "structFlash__DevConfig.html#aceece3d92326136df48c08aad0b56109", null ],
      [ "addrByteSupport", "structFlash__DevConfig.html#a3b7e99b80e5237d2b0bbf5c9d82b5a69", null ],
      [ "fourByteAddrEnSeq", "structFlash__DevConfig.html#aeea07d11c4e7bdafaeb17d5d07f56ea6", null ],
      [ "cmdWren", "structFlash__DevConfig.html#afe362f0bdd2a40fc03d2089e45daa312", null ],
      [ "cmdRdsr", "structFlash__DevConfig.html#a80726f5736774c6f94ae2985fe7f37f5", null ],
      [ "srWip", "structFlash__DevConfig.html#a58fcf27c6c42c987fc0f7ccdbf766aa9", null ],
      [ "srWel", "structFlash__DevConfig.html#aa34b6b36b967b4d9f0d6a6f67d90296d", null ],
      [ "resetType", "structFlash__DevConfig.html#ab283ed5ac28888b6d2f4ece2a2697e44", null ],
      [ "deviceBusyType", "structFlash__DevConfig.html#aa7a680fe04d589f1c8191cd822b8a305", null ],
      [ "xspiWipRdCmd", "structFlash__DevConfig.html#a3c1371c0b80f704be04ca418c1eb5bab", null ],
      [ "xspiWipReg", "structFlash__DevConfig.html#a14b9aeec3eab6912fa695762024d5a7f", null ],
      [ "xspiWipBit", "structFlash__DevConfig.html#af26d4f2cc7406d7d47b233d74813c859", null ],
      [ "flashWriteTimeout", "structFlash__DevConfig.html#a0db863ac98591c4b85c5fc302cba126d", null ],
      [ "flashBusyTimeout", "structFlash__DevConfig.html#a0fe9ca24c48903379733c815a3d96d0d", null ],
      [ "eraseCfg", "structFlash__DevConfig.html#a7cd4f1646878a255c5f42f94fb5f1dce", null ],
      [ "idCfg", "structFlash__DevConfig.html#aec4d61cd7bbcd19ee93805ec6ebd4203", null ],
      [ "protocolCfg", "structFlash__DevConfig.html#a47bc6a8e8e5de5fd6368cbca3331885a", null ]
    ] ],
    [ "Flash_Params", "structFlash__Params.html", [
      [ "quirksFxn", "structFlash__Params.html#af84f256d7f327843ed0ea6abdd7a59c8", null ],
      [ "custProtoFxn", "structFlash__Params.html#adbf8c9b96aeeeca61ee090ea1d0fe554", null ]
    ] ],
    [ "Flash_Fxns", "structFlash__Fxns.html", [
      [ "openFxn", "structFlash__Fxns.html#a33282037c2d497a3eac09fa35d9cf101", null ],
      [ "closeFxn", "structFlash__Fxns.html#aa1415bbaf626f2f0e423a3aed1385df7", null ],
      [ "readFxn", "structFlash__Fxns.html#a1ea1056103cb90dffb102efc9851fa9b", null ],
      [ "writeFxn", "structFlash__Fxns.html#af08a758ebcd6e677c3c1e295ce864f69", null ],
      [ "eraseFxn", "structFlash__Fxns.html#a70868dc6e7f457f10ffa666ede4aea15", null ],
      [ "eraseSectorFxn", "structFlash__Fxns.html#a188c641aa936112bf55838b157b6c75a", null ],
      [ "resetFxn", "structFlash__Fxns.html#a10e797df598663ad56a0de7fc97948e6", null ]
    ] ],
    [ "Flash_Attrs", "structFlash__Attrs.html", [
      [ "flashType", "structFlash__Attrs.html#a36c227118f5cc35e681ab38b5c59e3b9", null ],
      [ "flashName", "structFlash__Attrs.html#ae34fe8eae89a35ae61efc0d411762fa2", null ],
      [ "deviceId", "structFlash__Attrs.html#a488a47053e290feeda9e97c34f67953a", null ],
      [ "manufacturerId", "structFlash__Attrs.html#afbf10107b2ef425512e4cfa7125aafdb", null ],
      [ "driverInstance", "structFlash__Attrs.html#acf6f50dad133fc501c253b82cfca767e", null ],
      [ "flashSize", "structFlash__Attrs.html#a62a68cd8a1a760ac5aedfe3d63333c8f", null ],
      [ "blockCount", "structFlash__Attrs.html#a6368a95e532743116b74afe277349046", null ],
      [ "blockSize", "structFlash__Attrs.html#ae7e54e4ecf4cf409e3bdc469f8066f93", null ],
      [ "pageCount", "structFlash__Attrs.html#afb39b0edffaea99a900530066d6bb2f9", null ],
      [ "pageSize", "structFlash__Attrs.html#a5a30388ace38b4558c3f6a4e97bd6f47", null ],
      [ "sectorCount", "structFlash__Attrs.html#a5cfc97971673e73d889b25eafb805392", null ],
      [ "sectorSize", "structFlash__Attrs.html#a0739ae1cced960468b78744a35959098", null ]
    ] ],
    [ "Flash_Config", "structFlash__Config.html", [
      [ "attrs", "structFlash__Config.html#a5432fdd022fe3d125b81e44e003e9bbf", null ],
      [ "fxns", "structFlash__Config.html#a6155ab0b6c5dfdd4e06b1b51c032eccc", null ],
      [ "devConfig", "structFlash__Config.html#af8513dd274fc29a7fa4af0ca8437bb5c", null ],
      [ "object", "structFlash__Config.html#acdb5ad7537573eab6ed13155f9fcd9ea", null ]
    ] ],
    [ "Flash_Handle", "group__BOARD__FLASH__MODULE.html#ga0aa97d350ea7374b917f12dddc1abba4", null ],
    [ "Flash_Config", "group__BOARD__FLASH__MODULE.html#gabead45069a5ee9015a31b22f09689b30", null ],
    [ "Flash_Params", "group__BOARD__FLASH__MODULE.html#ga20003948729c78b783115ff42b00fe8b", null ],
    [ "Flash_OpenFxn", "group__BOARD__FLASH__MODULE.html#gac80b77da3e30699566045930ffba335e", null ],
    [ "Flash_CloseFxn", "group__BOARD__FLASH__MODULE.html#gafe3b9a7bb48ce68722cb734067b97bb7", null ],
    [ "Flash_ReadFxn", "group__BOARD__FLASH__MODULE.html#gaa0a1cfeaa72dec60180a6e7cf2e0f679", null ],
    [ "Flash_WriteFxn", "group__BOARD__FLASH__MODULE.html#ga0e08dba58e6a9583c59f545d1077313b", null ],
    [ "Flash_EraseFxn", "group__BOARD__FLASH__MODULE.html#ga437298b9ed14d4ae04328b60c6c090c6", null ],
    [ "Flash_EraseSectorFxn", "group__BOARD__FLASH__MODULE.html#gaacabf25be93442a09ea3563db3d33154", null ],
    [ "Flash_ResetFxn", "group__BOARD__FLASH__MODULE.html#ga890872ff2aa7b789f54d80ca4ee9f39f", null ],
    [ "Flash_quirksFxn", "group__BOARD__FLASH__MODULE.html#ga6a8fc7238066b55a7befe161e447ef64", null ],
    [ "Flash_custProtocolFxn", "group__BOARD__FLASH__MODULE.html#gadeb86f8db9fb0e614573ef99bcfd8b42", null ],
    [ "Flash_Params_init", "group__BOARD__FLASH__MODULE.html#ga548767b7c425042f55d8e5df0e9c3374", null ],
    [ "Flash_open", "group__BOARD__FLASH__MODULE.html#ga433c1193175febd7b27b3a305bd7d57c", null ],
    [ "Flash_close", "group__BOARD__FLASH__MODULE.html#ga0e5d8fc8573b2aa27461762fba84c3b3", null ],
    [ "Flash_getHandle", "group__BOARD__FLASH__MODULE.html#ga8697714617a2c5a2898d91f14105df9e", null ],
    [ "Flash_read", "group__BOARD__FLASH__MODULE.html#ga688fd20ef668ce16b8fd86fbb85a69c1", null ],
    [ "Flash_write", "group__BOARD__FLASH__MODULE.html#ga001f20252aa7da2e6a33036cd2d45178", null ],
    [ "Flash_blkPageToOffset", "group__BOARD__FLASH__MODULE.html#ga3b3c81381f3063fea3c428f63016ec89", null ],
    [ "Flash_offsetToBlkPage", "group__BOARD__FLASH__MODULE.html#ga011f0693fe6668e01b61e415a78a4586", null ],
    [ "Flash_SectorPageToOffset", "group__BOARD__FLASH__MODULE.html#ga984ff417303ac4f3939735f93105fb3f", null ],
    [ "Flash_offsetToSectorPage", "group__BOARD__FLASH__MODULE.html#gaa06c455af2ca8bd5ce78325b464aa1b5", null ],
    [ "Flash_eraseBlk", "group__BOARD__FLASH__MODULE.html#ga6871c4f81b71aa3543e8c37ace777821", null ],
    [ "Flash_eraseSector", "group__BOARD__FLASH__MODULE.html#ga8b34c2e7c8bb97c9d8c8a227e273c138", null ],
    [ "Flash_reset", "group__BOARD__FLASH__MODULE.html#ga6c12904c68ffc4c202616c621f36e38f", null ],
    [ "Flash_getPhyTuningOffset", "group__BOARD__FLASH__MODULE.html#gad8034938eca81084dbdcc548f37ef053", null ],
    [ "Flash_getAttrs", "group__BOARD__FLASH__MODULE.html#gab26c7728148eda750247aa3d0b6fbae4", null ]
];

==> mcu_plus_sdk_am263x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am263x_11_01_00_19_docs_only/docs/api_guide_am263x/group__BOARD__FLASH__MODULE.js <==
var group__BOARD__FLASH__MODULE =
[
    [ "Flash_NandConfig", "structFlash__NandConfig.html", [
      [ "cmdWrsr", "structFlash__NandConfig.html#a08f46b686caee1090d0a7a2d6a2b5174", null ],
      [ "cmdPageLoad", "structFlash__NandConfig.html#a1f2a71b95ea2120bdfa3ffa31529df63", null ],
      [ "cmdPageProg", "structFlash__NandConfig.html#ac26788435610e8982ae141039c374b91", null ],
      [ "srWipReg", "structFlash__NandConfig.html#a5bf41e1e7181d922bb7f31ff24dec4e6", null ],
      [ "xspiRdsrDummy", "structFlash__NandConfig.html#a7379c773feff9d3d9ffc369ef9c9717d", null ],
      [ "progStatusReg", "structFlash__NandConfig.html#af65ff3790948df048400a56d9684c83d", null ],
      [ "xspiProgStatusReg", "structFlash__NandConfig.html#a41cf4d4568b4b04f11d180b297d6673c", null ],
      [ "eraseStatusReg", "structFlash__NandConfig.html#ab04ae84b55ce949a3682c430b5ec0e33", null ],
      [ "xspiEraseStatusReg", "structFlash__NandConfig.html#a782a6418f669bcb4261513e37c47b916", null ],
      [ "srProgStatus", "structFlash__NandConfig.html#ae26fb17dbf1b97522965b1d4b67e7642", null ],
      [ "srEraseStatus", "structFlash__NandConfig.html#a5e22b8ea43397f302a338df558f40487", null ],
      [ "srWriteProtectReg", "structFlash__NandConfig.html#af151e797eaf119f15c9ecce04aebe7fa", null ],
      [ "srWriteProtectMask", "structFlash__NandConfig.html#a303a8c58aaac6b17b891e6e675ab0f6d", null ]
    ] ],
    [ "Flash_DevConfig", "structFlash__DevConfig.html", [
      [ "cmdExtType", "structFlash__DevConfig.html#af9aaea904629353d937dc22dc5837b94", null ],
      [ "byteOrder", "structFlash__DevConfig.html#a03033dffd93a0ad57463b274b0a83ff2", null ],
      [ "enable4BAddr", "structFlash__DevConfig.html#aceece3d92326136df48c08aad0b56109", null ],
      [ "addrByteSupport", "structFlash__DevConfig.html#a3b7e99b80e5237d2b0bbf5c9d82b5a69", null ],
      [ "fourByteAddrEnSeq", "structFlash__DevConfig.html#aeea07d11c4e7bdafaeb17d5d07f56ea6", null ],
      [ "cmdWren", "structFlash__DevConfig.html#afe362f0bdd2a40fc03d2089e45daa312", null ],
      [ "cmdRdsr", "structFlash__DevConfig.html#a80726f5736774c6f94ae2985fe7f37f5", null ],
      [ "srWip", "structFlash__DevConfig.html#a58fcf27c6c42c987fc0f7ccdbf766aa9", null ],
      [ "cmdPageLoadCyc1", "structFlash__DevConfig.html#a506fa24d7ae2fc51c2bedd573f08bacc", null ],
      [ "cmdPageLoadCyc2", "structFlash__DevConfig.html#a54c68798c25edf92571b16f19c6435f5", null ],
      [ "cmdRandomReadCyc1", "structFlash__DevConfig.html#ab2acdfad5f7e49651aff07b71fd31310", null ],
      [ "cmdRandomReadCyc2", "structFlash__DevConfig.html#a2b291686297c41f37b2c0a1f5fefff52", null ],
      [ "cmdRandomInput", "structFlash__DevConfig.html#a1e640a1a108f1648e1d72cc6910bb19c", null ],
      [ "cmdPageProgCyc1", "structFlash__DevConfig.html#a64568ae2281c278d4e88401d2bb4a874", null ],
      [ "cmdPageProgCyc2", "structFlash__DevConfig.html#a1ccea3c82914032656c760a5c28adeb1", null ],
      [ "pageColAddrCyc", "structFlash__DevConfig.html#a29a81dca04a0df2eee089f7b1f2d9353", null ],
      [ "pageRowAddrCyc", "structFlash__DevConfig.html#afab0fc477109d917238beffbee9712a0", null ],
      [ "cmdReadStatus", "structFlash__DevConfig.html#afb423a4bf94438d4e449227ca0c2596c", null ],
      [ "cmdReset", "structFlash__DevConfig.html#a4b9a8b5f73b7208bc365d78539c7c6d5", null ],
      [ "srWel", "structFlash__DevConfig.html#aa34b6b36b967b4d9f0d6a6f67d90296d", null ],
      [ "resetType", "structFlash__DevConfig.html#ab283ed5ac28888b6d2f4ece2a2697e44", null ],
      [ "deviceBusyType", "structFlash__DevConfig.html#aa7a680fe04d589f1c8191cd822b8a305", null ],
      [ "xspiWipRdCmd", "structFlash__DevConfig.html#a3c1371c0b80f704be04ca418c1eb5bab", null ],
      [ "xspiWipReg", "structFlash__DevConfig.html#a14b9aeec3eab6912fa695762024d5a7f", null ],
      [ "xspiWipBit", "structFlash__DevConfig.html#af26d4f2cc7406d7d47b233d74813c859", null ],
      [ "flashWriteTimeout", "structFlash__DevConfig.html#a0db863ac98591c4b85c5fc302cba126d", null ],
      [ "flashBusyTimeout", "structFlash__DevConfig.html#a0fe9ca24c48903379733c815a3d96d0d", null ],
      [ "eraseCfg", "structFlash__DevConfig.html#a7cd4f1646878a255c5f42f94fb5f1dce", null ],
      [ "idCfg", "structFlash__DevConfig.html#aec4d61cd7bbcd19ee93805ec6ebd4203", null ],
      [ "protocolCfg", "structFlash__DevConfig.html#a47bc6a8e8e5de5fd6368cbca3331885a", null ],
      [ "nandCfg", "structFlash__DevConfig.html#a98f44573a23b6366b4f5911fe930e52b", null ]
    ] ],
    [ "Flash_Params", "structFlash__Params.html", [
      [ "quirksFxn", "structFlash__Params.html#af84f256d7f327843ed0ea6abdd7a59c8", null ],
      [ "custProtoFxn", "structFlash__Params.html#adbf8c9b96aeeeca61ee090ea1d0fe554", null ]
    ] ],
    [ "Flash_Fxns", "structFlash__Fxns.html", [
      [ "openFxn", "structFlash__Fxns.html#a33282037c2d497a3eac09fa35d9cf101", null ],
      [ "closeFxn", "structFlash__Fxns.html#aa1415bbaf626f2f0e423a3aed1385df7", null ],
      [ "readFxn", "structFlash__Fxns.html#a1ea1056103cb90dffb102efc9851fa9b", null ],
      [ "writeFxn", "structFlash__Fxns.html#af08a758ebcd6e677c3c1e295ce864f69", null ],
      [ "eraseFxn", "structFlash__Fxns.html#a70868dc6e7f457f10ffa666ede4aea15", null ],
      [ "eraseSectorFxn", "structFlash__Fxns.html#a188c641aa936112bf55838b157b6c75a", null ],
      [ "resetFxn", "structFlash__Fxns.html#a10e797df598663ad56a0de7fc97948e6", null ],
      [ "enableDacModeFxn", "structFlash__Fxns.html#a6254564547e4ab2f04437ad5f6e03e06", null ],
      [ "disableDacModeFxn", "structFlash__Fxns.html#a2a2e6bba1dc3f3b11b62e551075a87f8", null ],
      [ "phyTuneFxn", "structFlash__Fxns.html#a74ab46d3d14c31dc1f3caab9113bb4b5", null ]
    ] ],
    [ "Flash_Attrs", "structFlash__Attrs.html", [
      [ "flashType", "structFlash__Attrs.html#a36c227118f5cc35e681ab38b5c59e3b9", null ],
      [ "flashName", "structFlash__Attrs.html#ae34fe8eae89a35ae61efc0d411762fa2", null ],
      [ "deviceId", "structFlash__Attrs.html#a488a47053e290feeda9e97c34f67953a", null ],
      [ "manufacturerId", "structFlash__Attrs.html#afbf10107b2ef425512e4cfa7125aafdb", null ],
      [ "driverInstance", "structFlash__Attrs.html#acf6f50dad133fc501c253b82cfca767e", null ],
      [ "flashSize", "structFlash__Attrs.html#a62a68cd8a1a760ac5aedfe3d63333c8f", null ],
      [ "blockCount", "structFlash__Attrs.html#a6368a95e532743116b74afe277349046", null ],
      [ "blockSize", "structFlash__Attrs.html#ae7e54e4ecf4cf409e3bdc469f8066f93", null ],
      [ "pageCount", "structFlash__Attrs.html#afb39b0edffaea99a900530066d6bb2f9", null ],
      [ "pageSize", "structFlash__Attrs.html#a5a30388ace38b4558c3f6a4e97bd6f47", null ],
      [ "sectorCount", "structFlash__Attrs.html#a5cfc97971673e73d889b25eafb805392", null ],
      [ "sectorSize", "structFlash__Attrs.html#a0739ae1cced960468b78744a35959098", null ],
      [ "spareAreaSize", "structFlash__Attrs.html#a7e718278a35ca3fd2cdcf3c2949ad20a", null ],
      [ "phyTuningOffset", "structFlash__Attrs.html#aff4d7214894937b329a7a36a24fcabce", null ]
    ] ],
    [ "Flash_Config", "structFlash__Config.html", [
      [ "attrs", "structFlash__Config.html#a5432fdd022fe3d125b81e44e003e9bbf", null ],
      [ "fxns", "structFlash__Config.html#a6155ab0b6c5dfdd4e06b1b51c032eccc", null ],
      [ "devConfig", "structFlash__Config.html#af8513dd274fc29a7fa4af0ca8437bb5c", null ],
      [ "object", "structFlash__Config.html#acdb5ad7537573eab6ed13155f9fcd9ea", null ],
      [ "skipHwInit", "structFlash__Config.html#ac0bc75373ec642eec1934a7a0399c50b", null ],
      [ "rwOffset", "structFlash__Config.html#abafe9fd498cad9c38defa06383183499", null ],
      [ "fallBackCfg", "structFlash__Config.html#a1a59751bde097d04063251b1e59b4b5b", null ]
    ] ],
    [ "Flash_Handle", "group__BOARD__FLASH__MODULE.html#ga0aa97d350ea7374b917f12dddc1abba4", null ],
    [ "Flash_Config", "group__BOARD__FLASH__MODULE.html#gabead45069a5ee9015a31b22f09689b30", null ],
    [ "Flash_Params", "group__BOARD__FLASH__MODULE.html#ga20003948729c78b783115ff42b00fe8b", null ],
    [ "Flash_OpenFxn", "group__BOARD__FLASH__MODULE.html#gac80b77da3e30699566045930ffba335e", null ],
    [ "Flash_CloseFxn", "group__BOARD__FLASH__MODULE.html#gafe3b9a7bb48ce68722cb734067b97bb7", null ],
    [ "Flash_ReadFxn", "group__BOARD__FLASH__MODULE.html#gaa0a1cfeaa72dec60180a6e7cf2e0f679", null ],
    [ "Flash_WriteFxn", "group__BOARD__FLASH__MODULE.html#ga0e08dba58e6a9583c59f545d1077313b", null ],
    [ "Flash_EraseFxn", "group__BOARD__FLASH__MODULE.html#ga437298b9ed14d4ae04328b60c6c090c6", null ],
    [ "Flash_EraseSectorFxn", "group__BOARD__FLASH__MODULE.html#gaacabf25be93442a09ea3563db3d33154", null ],
    [ "Flash_ResetFxn", "group__BOARD__FLASH__MODULE.html#ga890872ff2aa7b789f54d80ca4ee9f39f", null ],
    [ "Flash_EnableDacModeFxn", "group__BOARD__FLASH__MODULE.html#gac4357ffa2a86ca0ca6e526f78b2341d0", null ],
    [ "Flash_DisableDacModeFxn", "group__BOARD__FLASH__MODULE.html#gae7da8fb01d04a623d7d04c2b79d4d2e8", null ],
    [ "Flash_quirksFxn", "group__BOARD__FLASH__MODULE.html#ga6a8fc7238066b55a7befe161e447ef64", null ],
    [ "Flash_custProtocolFxn", "group__BOARD__FLASH__MODULE.html#gadeb86f8db9fb0e614573ef99bcfd8b42", null ],
    [ "Flash_phyTuneFxn", "group__BOARD__FLASH__MODULE.html#ga39875778449fda30dd84533f5a8e5332", null ],
    [ "Flash_Params_init", "group__BOARD__FLASH__MODULE.html#ga548767b7c425042f55d8e5df0e9c3374", null ],
    [ "Flash_open", "group__BOARD__FLASH__MODULE.html#ga433c1193175febd7b27b3a305bd7d57c", null ],
    [ "Flash_close", "group__BOARD__FLASH__MODULE.html#ga0e5d8fc8573b2aa27461762fba84c3b3", null ],
    [ "Flash_getHandle", "group__BOARD__FLASH__MODULE.html#ga8697714617a2c5a2898d91f14105df9e", null ],
    [ "Flash_read", "group__BOARD__FLASH__MODULE.html#ga688fd20ef668ce16b8fd86fbb85a69c1", null ],
    [ "Flash_write", "group__BOARD__FLASH__MODULE.html#ga001f20252aa7da2e6a33036cd2d45178", null ],
    [ "Flash_blkPageToOffset", "group__BOARD__FLASH__MODULE.html#ga3b3c81381f3063fea3c428f63016ec89", null ],
    [ "Flash_offsetToBlkPage", "group__BOARD__FLASH__MODULE.html#ga011f0693fe6668e01b61e415a78a4586", null ],
    [ "Flash_SectorPageToOffset", "group__BOARD__FLASH__MODULE.html#ga984ff417303ac4f3939735f93105fb3f", null ],
    [ "Flash_offsetToSectorPage", "group__BOARD__FLASH__MODULE.html#gaa06c455af2ca8bd5ce78325b464aa1b5", null ],
    [ "Flash_eraseBlk", "group__BOARD__FLASH__MODULE.html#ga6871c4f81b71aa3543e8c37ace777821", null ],
    [ "Flash_eraseSector", "group__BOARD__FLASH__MODULE.html#ga8b34c2e7c8bb97c9d8c8a227e273c138", null ],
    [ "Flash_reset", "group__BOARD__FLASH__MODULE.html#ga6c12904c68ffc4c202616c621f36e38f", null ],
    [ "Flash_enableDacMode", "group__BOARD__FLASH__MODULE.html#gaa36b595a17f4756ce41487fa842632a9", null ],
    [ "Flash_disableDacMode", "group__BOARD__FLASH__MODULE.html#gaebea4e04f838b98f54792c0e79ac83a4", null ],
    [ "Flash_getPhyTuningOffset", "group__BOARD__FLASH__MODULE.html#gad8034938eca81084dbdcc548f37ef053", null ],
    [ "Flash_getAttrs", "group__BOARD__FLASH__MODULE.html#gab26c7728148eda750247aa3d0b6fbae4", null ],
    [ "Flash_phyTune", "group__BOARD__FLASH__MODULE.html#gac4353f83384e9f69996ff3c80defa1f0", null ]
];
